@@ -42,7 +42,7 @@ class ModelAnalyzer:
                 X_test: pd.DataFrame, y_test: pd.Series,
                 model, plot_shap_values: bool = True, coefficients: bool = True,
                 confusion_matrix: bool = True,
-                roc_curve: bool = True, learning_curve: bool = False,
+                roc_curve: bool = True, learning_curve: bool = True,
                 feature_importance: bool = True) -> None:
         unique_classes = len(np.unique(y_train))
         if feature_importance:
