@@ -3,7 +3,7 @@ from collections import Counter
 import matplotlib
 import pandas as pd
 from flatbuffers.builder import np
-from sklearn.datasets import fetch_20newsgroups
+from sklearn.datasets import fetch_20newsgroups, fetch_openml
 
 from chester.data_loader.webtext_data import load_data_pirates, load_data_king_arthur, load_data_chat_logs
 from chester.run.full_run import run_madcat
@@ -13,12 +13,12 @@ matplotlib.use('TkAgg')
 target_column = 'target'
 
 ################################################################################################
-df1 = load_data_pirates().assign(target='pirate').sample(300, replace=True)
-df2 = load_data_king_arthur().assign(target='arthur').sample(300, replace=True)
-df3 = load_data_chat_logs().assign(target='chat').sample(300, replace=True)
-df = pd.concat([df1, df2
-                # , df3
-                ])
+# df1 = load_data_pirates().assign(target='pirate').sample(300, replace=True)
+# df2 = load_data_king_arthur().assign(target='arthur').sample(300, replace=True)
+# df3 = load_data_chat_logs().assign(target='chat').sample(300, replace=True)
+# df = pd.concat([df1, df2
+#                 , df3
+#                 ])
 
 
 # df['target'] = df['target'].apply(lambda x: 0 if "pirate" in x else 1)  # can do with or without
@@ -36,9 +36,9 @@ df = pd.concat([df1, df2
 
 ###############################################################################################
 # Load the Boston Housing dataset. categorical
-# boston = fetch_openml(name='boston', version=1)
-# df = pd.DataFrame(boston.data, columns=boston.feature_names)
-# df['target'] = boston.target
+boston = fetch_openml(name='boston', version=1)
+df = pd.DataFrame(boston.data, columns=boston.feature_names)
+df['target'] = boston.target
 ###############################################################################################
 
 ###############################################################################################
@@ -177,9 +177,9 @@ def load_ex5():
 
 
 madcat_collector = run_madcat(Data(df=df, target_column='target'),
-                              is_feature_stats=True,
+                              is_feature_stats=False,
                               is_pre_model=True,
-                              is_model_training=True,
+                              is_model_training=False,
                               model_run=ModelRun(n_models=3),
                               is_post_model=True, is_model_weaknesses=True
                               )
